require "asm/private_util"
require "asm/network_configuration"
require "asm/processor/linux_post_os"

module ASM
  module Processor
    class LinuxVMPostOS < ASM::Processor::LinuxPostOS
      def initialize(service_deployment, component)
        @vm_component = component
        @sd = service_deployment
        @vm_config = ASM::PrivateUtil.build_component_configuration(component, :decrypt => service_deployment.decrypt?)
        @vm_cert = @vm_component["puppetCertName"]
        @vm_params = vm_params
        super(service_deployment, component)
      end

      def vm_params
        @vm_params ||= begin
          if @vm_config["asm::vm::vcenter"]
            (@vm_config["asm::vm::vcenter"] || {})[@vm_cert]
          elsif @vm_config["asm::vm::scvmm"]
            (@vm_config["asm::vm::scvmm"] || {})[@vm_cert]
          end
        end
      end

      def vm_networks
        @networks = @vm_params["network_interfaces"] || {}
      end

      def logger
        @sd.logger
      end

      def default_gateway_network
        @vm_params.fetch("default_gateway", "")
      end

      def default_gateway_network_config
        logger.debug("Looking for network by the id, #{default_gateway_network}")
        def_network = vm_networks.find {|network| network["id"] == default_gateway_network}
        if def_network
          {"network::global" => {"gateway" => def_network["staticNetworkConfiguration"]["gateway"]}}
        else
          {}
        end
      end

      def post_os_config(puppet_hash={})
        logger.debug("Setting the default gateway if requested")
        puppet_hash["classes"] ||= {}
        puppet_hash["classes"].merge!(default_gateway_network_config)

        logger.debug("Starting to process puppet resources for VM static NIC")
        puppet_hash["resources"] ||= {}
        puppet_hash["resources"] = process_network_config

        logger.debug("Linux Post OS puppet config: #{puppet_hash}")

        puppet_hash
      end

      def process_network_config
        net_config = {}
        seq = 0
        vm_networks.each do |network|
          logger.debug("Processing network, #{network}, into puppet config")
          if network["static"]
            net_config["network::if::static"] ||= {}
            net_config["network::if::static"][seq] = {
              "ensure" => "up",
              "ipaddress" => network["staticNetworkConfiguration"]["ipAddress"],
              "netmask" => network["staticNetworkConfiguration"]["subnet"],
              "gateway" => (network["staticNetworkConfiguration"]["gateway"] || ""),
              "domain" => (network["staticNetworkConfiguration"]["dnsSuffix"] || ""),
              "defroute" => "no"
            }
            if network["id"] == default_gateway_network
              net_config["network::if::static"][seq]["defroute"] = "yes"
            end
          else
            net_config["network::if::dynamic"] ||= {}
            net_config["network::if::dynamic"][seq] = {
              "ensure" => "up"
            }
          end
          # the seq still has to be incremented to preserve the order of network interfaces on the VM
          seq += 1
        end

        net_config
      end
    end
  end
end
