require "asm/provider/switch/base"

module ASM
  class Provider
    class Switch
      class Brocade < Switch::Base
        puppet_type "brocade::createzone"

        PROVIDER_JSON_FACTS = [
          "Aliases_Members"
        ].freeze

        def self.handles_switch?(switch)
          !!(switch["refId"] =~ /^brocade_fos/)
        end

        def rack_switch?
          true
        end

        def san_switch?
          true
        end

        def find_mac(mac)
          return nil unless facts && facts.include?("RemoteDeviceInfo")

          interface = facts["RemoteDeviceInfo"].find do |_, dets|
            dets["mac_address"].include?(mac.downcase)
          end

          interface ? interface.first : nil
        end

        def fc_zones(wwpn=nil)
          return facts["Zones"] unless wwpn

          facts["Zone_Members"].map do |zone, members|
            zone if members.map(&:downcase).include?(wwpn.downcase)
          end.compact
        end

        # Additional normalization of facts needed for Brocade switches
        def normalise_facts!
          super

          if facts.include?("RemoteDeviceInfo ") && !facts["RemoteDeviceInfo "].empty?
            facts["RemoteDeviceInfo"] = facts.delete("RemoteDeviceInfo ")
          end

          # when blades connect through an IOA the one port will see many
          # connected servers but they are \n\t seperates are they are direct
          # from the switch output.  This just turns that into a array
          facts["RemoteDeviceInfo"].each do |_, remote|
            remote["mac_address"] = remote["mac_address"].split("\n\t")
          end

          facts["Zones"] = facts["Zones"].split(/,\s+/).sort.uniq
          facts["Alias"] = facts["Alias"].split(/,\s+/).sort.uniq

          facts["Alias"].each do |switch_alias|
            parse_json_fact(switch_alias)
          end
        end
      end
    end
  end
end
