require "asm/provider/switch/base"

module ASM
  class Provider
    class Switch
      class Powerconnect < Switch::Base
        puppet_type "dell_powerconnect"

        def self.handles_switch?(switch)
          switch["refId"].start_with?("dell_powerconnect")
        end

        def server_supported?(server)
          return true if server.rack_server? && rack_switch?
          false
        end

        def load_switch_creator
          path = "asm/provider/switch/powerconnect/rack.rb"
          logger.debug("Configure %s using %s" % [type.puppet_certname, path])
          require path
        end

        def resource_creator!
          load_switch_creator
          self.resource_creator = Rack.new(self)
        end

        def rack_switch?
          true
        end

        def blade_switch?
          false
        end

        # (see ASM::Type::Server#configure_server)
        def configure_server(server, staged)
          provision_server_networking(server)
          process! unless staged
        end

        # Configures each partition as per the template
        #
        # @param server [ASM::Type::Server]
        # @return [void]
        def provision_server_networking(server)
          server.configured_interfaces.each do |interface|
            provision_server_interface(server, interface)
          end
        end
      end
    end
  end
end
