require 'spec_helper'

$LOAD_PATH << File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "..", "..", "nagios"))

require 'check_snmp'

describe "When checking SNMP devices" do
  before do
    @options = {:host => "rspec",
                :vendor => "Dell"}

    @check = ASM::Nagios::CheckSnmp.new(@options)
  end

  it "should report green" do
    vendor = "Dell"
    model = "S4810"
    state = "ok"
    @device = @check.create_device(vendor,model)
    @device.results_cache = SpecHelper.json_fixture("snmp/%s/%s_%s.json"%[vendor,model,state])
    status,message = @device.query_snmp(@options).should == [0,"OK"]
  end

  it "should report yellow for power off" do
    vendor = "Dell"
    model = "S4810"
    state = "warning"
    @device = @check.create_device(vendor,model)
    @device.results_cache = SpecHelper.json_fixture("snmp/%s/%s_%s.json"%[vendor,model,state])
    status,message = @device.query_snmp(@options).should == [1,"Power:Down"]
  end

  it "should report critical for fan down" do
    vendor = "Dell"
    model = "S4810"
    state = "critical"
    @device = @check.create_device(vendor,model)
    @device.results_cache = SpecHelper.json_fixture("snmp/%s/%s_%s.json"%[vendor,model,state])
    status,message = @device.query_snmp(@options).should == [2,"unitStatus:UnitDown,Fan:Down,Power:Down"]
  end

  it "should report yellow for power not present" do
    vendor = "Dell"
    model = "Dell Networking N3024"
    state = "warning"
    @device = @check.create_device(vendor,model)
    @device.results_cache = SpecHelper.json_fixture("snmp/%s/%s_%s.json"%[vendor,model,state])
    status,message = @device.query_snmp(@options).should == [1,"Power:notPresent"]
  end

  it "should report yellow for fans and power shutdown state" do
    vendor = "Dell"
    model = "Dell Networking N4064F"
    state = "warning"
    @device = @check.create_device(vendor,model)
    @device.results_cache = SpecHelper.json_fixture("snmp/%s/%s_%s.json"%[vendor,model,state])
    status,message = @device.query_snmp(@options).should == [1,"Fan:shutdown,Power:shutdown"]
  end
end
